@@ -103,7 +103,7 @@ panel_applet_frame_load_from_gconf (PanelWidget *panel_widget,
 	temp_key = panel_gconf_full_key (PANEL_GCONF_APPLETS, profile, gconf_key, "bonobo_iid");
 	applet_iid = gconf_client_get_string (client, temp_key, NULL);
 
-	panel_applet_frame_load (applet_iid, panel_widget, position, gconf_key);
+	panel_applet_frame_load (applet_iid, panel_widget, position, TRUE, gconf_key);
 
 	g_free (applet_iid);
 }
@@ -148,7 +148,8 @@ static BonoboUIVerb popup_verbs [] = {
 void
 panel_applet_frame_load (const gchar *iid,
 			 PanelWidget *panel,
-			 gint         pos,
+			 int          position,
+			 gboolean     exactpos,
 			 const char  *gconf_key)
 {
 	GtkWidget  *frame = NULL;
@@ -165,15 +166,15 @@ panel_applet_frame_load (const gchar *iid,
 
 	frame = panel_applet_frame_new (panel, iid, real_key);
 
-	if (!frame)
+	if (!frame) {
+		g_free (real_key);
 		return;
+	}
 	
 	gtk_widget_show_all (frame);
 
-	/* Pass frame as 2nd argument, since it is used in
-	 * panel_remove_applets()  */
-	info = panel_applet_register (frame, frame, NULL, panel, pos,
-				      FALSE, APPLET_BONOBO, real_key);
+	info = panel_applet_register (frame, frame, NULL, panel, position,
+				      exactpos, APPLET_BONOBO, real_key);
 
 	if (!info)
 		g_warning (_("Cannot register control widget\n"));
@@ -624,11 +625,19 @@ panel_applet_frame_reload_response (GtkWidget        *dialog,
 				    int               response,
 				    PanelAppletFrame *frame)
 {
-	AppletInfo *info = frame->priv->applet_info;
+	AppletInfo *info;
 
-	if (response == GTK_RESPONSE_NO)
-		panel_applet_clean (info, TRUE);
-	else {
+	g_return_if_fail (PANEL_IS_APPLET_FRAME (frame));
+
+	if (!GTK_WIDGET (frame)->parent) {
+		g_object_unref (frame);
+		gtk_widget_destroy (dialog);
+		return;
+	}
+
+	info = frame->priv->applet_info;
+
+	if (response == GTK_RESPONSE_YES) {
 		PanelWidget *panel;
 		char        *iid;
 		char        *gconf_key;
@@ -641,12 +650,14 @@ panel_applet_frame_reload_response (GtkWidget        *dialog,
 
 		panel_applet_clean (info, FALSE);
 
-		panel_applet_frame_load (iid, panel, position, gconf_key);
+		panel_applet_frame_load (iid, panel, position, TRUE, gconf_key);
 
 		g_free (iid);
 		g_free (gconf_key);
-	}
+	} else
+		panel_applet_clean (info, TRUE);
 
+	g_object_unref (frame);
 	gtk_widget_destroy (dialog);
 }
 
@@ -660,7 +671,7 @@ panel_applet_frame_get_name (char *iid)
 	query = g_strdup_printf ("iid == '%s'", iid);
 
 	list = bonobo_activation_query (query, NULL, NULL);
-	if (list) {
+	if (list && list->_length > 0 && list->_buffer) {
 		Bonobo_ServerInfo *info = &list->_buffer [0];
 		const GList       *langs_glist;
 		GSList            *langs_gslist;
@@ -701,7 +712,7 @@ panel_applet_frame_cnx_broken (PanelAppletFrame *frame)
 			  "Reload this applet?\n\n"
 			  "(If you choose not to reload it at this time"
 			  " you can always add it by right clicking on "
-			  "the panel and clicking on the \"Add to panel\""
+			  "the panel and clicking on the \"Add to Panel\""
 			  " submenu)"), applet_name ? applet_name : "");
 
 	dialog = gtk_message_dialog_new (
@@ -713,7 +724,7 @@ panel_applet_frame_cnx_broken (PanelAppletFrame *frame)
 
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (panel_applet_frame_reload_response),
-			  frame);
+			  g_object_ref (frame));
 
 	gtk_widget_show (dialog);
 	g_free (applet_name);
@@ -922,6 +933,19 @@ panel_applet_frame_construct (PanelAppletFrame *frame,
 			   "Details: %s"),
 			  iid, err);
 
+		/* FIXME: 2.2.x addition: #89173
+		 * 
+		 * Instead of automatically removing the applet from the
+		 * configuration the above dialog should read:
+		 *
+		 * There was a problem loading applet 'blah'.
+		 * 
+		 * Remove this applet from you configuration ?
+		 *
+		 *                              [Don't Remove] [[Remove]]
+		 */
+		panel_applet_clean_gconf (APPLET_BONOBO, gconf_key, TRUE);
+
 		CORBA_exception_free (&ev);
 
 		g_free (err);
