@@ -1220,15 +1220,16 @@ panel_stretch_events_to_toplevel (GtkWidget         *widget,
 
 /* stolen from gtk */
 void
-panel_signal_connect_while_alive (GObject     *object,
-				  const gchar *signal,
-				  GCallback    func,
-				  gpointer     func_data,
-				  GObject     *alive_object)
+panel_signal_connect_while_alive (gpointer    object,
+				  const char *signal,
+				  GCallback   func,
+				  gpointer    func_data,
+				  gpointer    alive_object)
 {
 	GClosure *closure;
 
 	g_return_if_fail (G_IS_OBJECT (object));
+	g_return_if_fail (G_IS_OBJECT (alive_object));
 
 	closure = g_cclosure_new (func, func_data, NULL);
 	g_object_watch_closure (G_OBJECT (alive_object), closure);
@@ -1239,17 +1240,18 @@ panel_signal_connect_while_alive (GObject     *object,
 }
 
 void
-panel_signal_connect_object_while_alive (GObject      *object,
-					 const gchar  *signal,
-					 GCallback     func,
-					 GObject      *alive_object)
+panel_signal_connect_object_while_alive (gpointer    object,
+					 const char *signal,
+					 GCallback   func,
+					 gpointer    alive_object)
 {
-  g_return_if_fail (G_IS_OBJECT (object));
+	g_return_if_fail (G_IS_OBJECT (object));
+	g_return_if_fail (G_IS_OBJECT (alive_object));
   
-  g_signal_connect_closure_by_id (object,
-				  g_signal_lookup (signal, G_OBJECT_TYPE (object)), 0,
-				  g_cclosure_new_object_swap (func, G_OBJECT (alive_object)),
-				  FALSE);
+	g_signal_connect_closure_by_id (object,
+					g_signal_lookup (signal, G_OBJECT_TYPE (object)), 0,
+					g_cclosure_new_object_swap (func, G_OBJECT (alive_object)),
+					FALSE);
 }
 
 gboolean
@@ -1424,81 +1426,35 @@ panel_uri_exists (const char *uri)
 	return ret;
 }
 
-#if 0
-/* hmmm, we need to use this I think to add a battery applet
- *  -George */
-/* Linux Battery Stuff */
-
-static gboolean
-linux_battery_exists (void)
+GdkPixbuf *
+missing_pixbuf (int size)
 {
-        FILE *fp;
-        char buf[200] = "";
-        int foo;
+	int i, j;
+	int rowstride;
+	guchar *pixels;
+	GdkPixbuf *pb;
 
-        if ( ! g_file_test ("/proc/apm", G_FILE_TEST_EXISTS))
-                return FALSE;
+	pb = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
+			     FALSE /* has alpha */,
+			     8 /* bits per sample */,
+			     size, size);
+	pixels = gdk_pixbuf_get_pixels (pb);
+	rowstride = gdk_pixbuf_get_rowstride (pb);
 
-        fp = fopen ("/proc/apm", "r");
-        if (fp == NULL)
-                return FALSE;
+	for (i = 0; i < size; i++) {
+		for (j = 0; j < size; j++) {
+			guchar *p = pixels + i * rowstride + 3 * j;
+			if (i == j || size - i == j) {
+				p[0] = 255;
+				p[1] = 0;
+				p[2] = 0;
+			} else {
+				p[0] = 255;
+				p[1] = 255;
+				p[2] = 255;
+			}
+		}
+	}
 
-        if (fgets (buf, sizeof (buf), fp) == NULL) {
-                fclose (fp);
-                return FALSE;
-        }
-        fclose (fp);
-
-        foo = -1;
-        sscanf (buf,
-                "%*s %*d.%*d %*x %*x %*x %*x %d%% %*d %*s\n",
-                &foo);
-
-        if (foo >= 0)
-                return TRUE;
-        else
-                return FALSE;
+	return pb;
 }
-
-static gboolean
-battery_exists (void)
-{
-#ifndef __linux__
-        return FALSE;
-#else
-        /* This is MUUUUCHO ugly, but apparently RH 7.0 with segv the program
-         * reading /proc/apm on some laptops, and we don't want to crash, thus
-         * we do the check in a forked process */
-        int status;
-        pid_t pid;
-
-        pid = fork ();
-        if (pid == 0) {
-                struct sigaction sa = {{NULL}};
-
-                sa.sa_handler = SIG_DFL;
-
-                sigaction(SIGSEGV, &sa, NULL);
-                sigaction(SIGFPE, &sa, NULL);
-                sigaction(SIGBUS, &sa, NULL);
-
-                if (linux_battery_exists ())
-                        _exit (0);
-                else
-                        _exit (1);
-        }
-
-        status = 0;
-        waitpid (pid, &status, 0);
-
-        if ( ! WIFSIGNALED (status) &&
-            WIFEXITED (status) &&
-            WEXITSTATUS (status) == 0) {
-                return TRUE;
-        } else {
-                return FALSE;
-        }
-#endif
-}
-
-#endif
